Module error

Module error 

Tauri-compatible error types

Tauri commands require errors to implement Serialize, so we use a dedicated error type instead of anyhow::Error.

Enums

TauriServerError
Errors returned by AllFrame Tauri commands