Tauri-compatible error types
Tauri commands require errors to implement Serialize,
so we use a dedicated error type instead of anyhow::Error.
Enums
- Tauri
Server Error - Errors returned by AllFrame Tauri commands
Tauri-compatible error types
Tauri commands require errors to implement Serialize,
so we use a dedicated error type instead of anyhow::Error.